--[[
	##AddOn	: ShortenGold
	##Subfile 	: main.lua
	##Author 	: Hati ( xhatix on wowace.com )
--]]
local SG = CreateFrame("Frame",nil)
SG:RegisterEvent("PLAYER_LOGOUT") --DB saving event
local tinsert,gsub,strlower = tinsert,gsub,strlower
local texturePaths = { --static
    "|TInterface\\MoneyFrame\\UI-GoldIcon:14:14:2:0|t",
    "|TInterface\\MoneyFrame\\UI-SilverIcon:14:14:2:0|t",
    "|TInterface\\MoneyFrame\\UI-CopperIcon:14:14:2:0|t",
}
local origCashFlowMsg;
local impCashFlowMsg = "You loot %s (%s for Guild)";

local replaceBy = { } --dynamic
SG:SetScript('OnEvent',function(self,event,...)
    if SG.db then 
        _G.ShortenGoldLoot_DB = SG.db
    end
end)

SG.ReplaceMsg = function(self,text)
    for index,type in ipairs(SG.locale) do
        --print(text,type,replaceTextures[index])
        text=string.gsub(text,type.."%,?",replaceBy[type] or "")
    end
    return text
end

SG.InitLocale = function()
	origCashFlowMsg = YOU_LOOT_MONEY_GUILD; --
    SG.locale = {}
    if not SG.db then SG.db=SG:InitDB() end
    local gold,silver,copper = strsub(GOLD_AMOUNT,3),strsub(SILVER_AMOUNT,3),strsub(COPPER_AMOUNT,3)
	if SG.db.coinicons then		
		tinsert(SG.locale,gold)
		tinsert(SG.locale,silver)
		tinsert(SG.locale,copper)
	end
    replaceBy[gold] = texturePaths[1]
    replaceBy[silver] = texturePaths[2]
    replaceBy[copper] = texturePaths[3]
    if SG.db.cashflow then
        tinsert(SG.locale,"%s?%b()")
    end
	if SG.db.cashflow2 then
		YOU_LOOT_MONEY_GUILD = impCashFlowMsg;
	end
end

SG.GoldReplace = function(self,event,msg,author,...)
    if not SG.locale then SG:InitLocale() end
    return false, SG:ReplaceMsg(msg),author,...
end
ChatFrame_AddMessageEventFilter("CHAT_MSG_MONEY",SG.GoldReplace)
--/MainCode

--\OptionCoded
local dftldb={
    coinicons=true,
    cashflow=false,
	cashflow2=true,
}
SG.InitDB = function(self)
    local db = _G.ShortenGoldLoot_DB
    if not (type(db)=='table') then
        db = { }
		db.coinicons = true
        db.cashflow = false
		db.cashflow2 = true
    else
        for entry,value in pairs(dftldb) do
            if db[entry]==nil then db[entry]=value end
        end
    end
	return db
end

local function ToggleCashFlow()
    if SG.db.cashflow then --disable
        print('ShortenGoldLoot: Cashflow is now shown again.')
        tDeleteItem(SG.locale,"%s%b()")
        SG.db.cashflow=false
    else
        print('ShortenGoldLoot: Cashflow addition is now hidden.')
        tinsert(SG.locale,"%s%b()")
        SG.db.cashflow=true
    end
end
local function ToggleCashFlow2()
	if SG.db.cashflow2 then
		print("ShortenGoldLoot: CashFlow addition changed to \"You loot #Amount# (#GAmount# for Guild)\"")
		YOU_LOOT_MONEY_GUILD = impCashFlowMsg;
	else
		print("ShortenGoldLoot: CashFlow addition changed back to blizzard's default message.")
		YOU_LOOT_MONEY_GUILD = origCashFlowMsg;
	end
	SG.db.cashflow2 = not SG.db.cashflow2
end
local function ToggleCoinIcons()
	local gold,silver,copper = strsub(GOLD_AMOUNT,3),strsub(SILVER_AMOUNT,3),strsub(COPPER_AMOUNT,3)
	if SG.db.coinicons then --disable
		print('ShortenGoldLoot: CoinIcons is now disabled.')
		tDeleteItem(SG.locale,gold)
		tDeleteItem(SG.locale,silver)
		tDeleteItem(SG.locale,copper)
		SG.db.coinicons = false
	else
		print('ShortenGoldLoot: CoinIcons is now enabled.')
		tinsert(SG.locale,gold)
		tinsert(SG.locale,silver)
		tinsert(SG.locale,copper)
		SG.db.coinicons = true
	end
end

local optionText = {
    --cmd -> function
    ["cashflow"] = ToggleCashFlow,
	["cashflow2"] = ToggleCashFlow2,
	["coinicons"] = ToggleCoinIcons
}

local function validFunc(name)
    for opt,_ in pairs(optionText) do
        if opt==name then return true end
    end
end

SLASH_ShortenGoldLoot1 = '/sgl'
SLASH_ShortenGoldLoot2 = '/shortengoldloot'
function SlashCmdList.ShortenGoldLoot(msg,editbox)
    if not SG.locale then SG:InitLocale() end
	msg = strlower(msg)
    if validFunc(msg) then
        optionText[msg]()
    else
        print("ShortenGoldLoot: valid slash commands")
        print("/sgl")
        print("* cashflow  - Toggles CashFlow addition to Goldloot-text")
		print("* cashflow2 - Changes CashFlow addition to \"(Gold silver copper for Guild)\" Only works if cashflow addition is shown.")
		print("* coinicons - Toggles Gold/Silver/Copper texturing")
    end
end
--/OptionCode